@@ -5,7 +5,7 @@ use warnings;
 use Carp;
 use List::Util qw( shuffle );
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 # fill the structure with the themes data
 our %META;
@@ -210,6 +210,8 @@ See C<name()>. The default is the same as for the OO interface.
 
 =item metafoo
 
+=item metajamesbond
+
 =item metapynchon
 
 =item metarobin
@@ -264,6 +266,10 @@ The characters from the popular serial.
 
 The classic. This is the default theme.
 
+=item jamesbond
+
+The list of James Bond movies.
+
 =item pynchon
 
 Character names from Thomas Pynchon's books.
@@ -316,7 +322,8 @@ This module could not have been possible without:
 =item Some sillyness
 
 See L<http://use.perl.org/~BooK/journal/22301>,
-and the follow-up L<http://use.perl.org/~BooK/journal/22710>.
+the follow-up L<http://use.perl.org/~BooK/journal/22710>,
+and the announce L<http://use.perl.org/~BooK/journal/22732>.
 
 =item The Batman serial from the 60s (it was shown in France in the 80s).
 
@@ -746,3 +753,11 @@ pe pf pg ph pk pl pm pn pr ps pt pw py qa re ro ru rw sa sb sc sd se sg sh
 si sj sk sl sm sn so sr st su sv sy sz tc td tf tg th tj tk tl tm tn to tp
 tr tt tv tw tz ua ug uk um us uy uz va vc ve vg vi vn vu wf ws ye yt yu za
 zm zr zw biz com edu gov int mil net org pro aero arpa coop info name nato
+# jamesbond
+Die_Another_Day                 The_World_is_Not_Enough
+Tomorrow_Never_Dies             GoldenEye             Licence_To_Kill
+The_Living_Daylights            A_View_to_a_Kill      Octopussy           
+For_Your_Eyes_Only              Moonraker             The_Spy_Who_Loved_Me 
+The_Man_With_the_Golden_Gun     Live_and_Let_Die      Diamonds_Are_Forever  
+On_Her_Majesty_s_Secret_Service You_Only_Live_Twice   Thunderball     
+Goldfinger                      From_Russia_With_Love Dr_No
